<?php
/**
* Plugin Class for CPT
*/
class Image_Caption_Hover_CPT
{
    
    function __construct(){
        add_action( 'admin_enqueue_scripts', array($this, 'loading_scripts_admin'));
        add_shortcode( 'ichcpt', array($this, 'render_ich_shortcode') );
        add_action( 'init', array($this, 'register_ich_cpt') );
        add_action( 'add_meta_boxes', array($this, 'ich_settings_box') );
        add_action( 'wp_enqueue_scripts', array($this, 'loading_front_scripts') );
        add_action( 'save_post', array($this, 'saving_ich_cpt') );

        add_filter('manage_ich_cpt_posts_columns', array($this, 'ich_cpt_column_head'));
        add_action('manage_ich_cpt_posts_custom_column', array($this, 'ich_cpt_column_content'), 10, 2);
    }

    /**
    * Registers a new post type
    * @uses $wp_post_types Inserts new post type object into the list
    *
    * @param string  Post type key, must not exceed 20 characters
    * @param array|string  See optional args description above.
    * @return object|WP_Error the registered post type object, or an error object
    */
    function register_ich_cpt() {
    
        $custom_labels = array(
            'name'                => __( 'Image Caption Hover', 'ich-effects' ),
            'singular_name'       => __( 'Image Caption Hover', 'ich-effects' ),
            'add_new'             => _x( 'Add New', 'ich-effects', 'ich-effects' ),
            'add_new_item'        => __( 'Add New', 'ich-effects' ),
            'name_admin_bar'        => __( 'Image Caption Hover', 'ich-effects' ),
            'edit_item'           => __( 'Edit', 'ich-effects' ),
            'new_item'            => __( 'New', 'ich-effects' ),
            'view_item'           => __( 'View', 'ich-effects' ),
            'search_items'        => __( 'Search', 'ich-effects' ),
            'not_found'           => __( 'No Image Caption Hover found', 'ich-effects' ),
            'not_found_in_trash'  => __( 'No Image Caption Hover found in Trash', 'ich-effects' ),
            'parent_item_colon'   => __( 'Parent:', 'ich-effects' ),
            'menu_name'           => __( 'Image Caption Hover', 'ich-effects' ),
            'all_items'           => __( 'View All', 'ich-effects' ),
        );
    
        $anim_args = array(
            'labels'              => $custom_labels,
            'hierarchical'        => false,
            'description'         => 'Fancy Grid Gallery',
            'public'              => false,
            'show_ui'             => true,
            'show_in_menu'        => true,
            'show_in_admin_bar'   => true,
            'menu_position'       => null,
            'menu_icon'           => 'dashicons-screenoptions',
            'show_in_nav_menus'   => false,
            'publicly_queryable'  => true,
            'exclude_from_search' => true,
            'has_archive'         => false,
            'query_var'           => true,
            'can_export'          => true,
            'rewrite'             => true,
            'capability_type'     => 'post',
            'supports'            => array(
                'title'
                )
        );
    
        register_post_type( 'ich_cpt', $anim_args );
    }
    

    function loading_scripts_admin($check){
        global $post;
        if ( $check == 'post-new.php' || $check == 'post.php' || 'edit.php') {
            if (isset($post->post_type) && 'ich_cpt' === $post->post_type) {
                wp_enqueue_style( 'wp-color-picker' );
                wp_enqueue_script( 'wp-color-picker-alpha', plugins_url( 'js/wp-color-picker-alpha.min.js', __FILE__ ), array( 'wp-color-picker' ));
                wp_enqueue_media();
                wp_enqueue_script( 'ichcpt-admin', plugin_dir_url( __FILE__ ). '/admin/cpt.js', array('jquery', 'wp-color-picker', 'jquery-ui-sortable', 'jquery-ui-accordion'));
                wp_enqueue_style( 'jquery-ui-theme', plugin_dir_url( __FILE__ ). '/css/jquery-ui.theme.min.css');
            }
        }
    }

    function loading_front_scripts(){

    }

    function render_ich_shortcode($atts){

        wp_enqueue_style( 'wc-simple-grid', plugin_dir_url( __FILE__ ). 'css/simplegrid.css');
        wp_enqueue_style( 'wcp-caption-styles', plugin_dir_url( __FILE__ ) .'css/style.css' );
        wp_enqueue_script( 'wcp-caption-scripts', plugin_dir_url( __FILE__ ) . 'js/script.js', array('jquery') );
        
        ob_start();
            include 'cpt_inc/render_shortcode.php';
        return ob_get_clean();

    }

    function ich_settings_box() {
        add_meta_box( 'ichcpt_options', 'Images', array($this, 'ichcpt_contents_mb'), 'ich_cpt');
        add_meta_box( 'ichcpt_shortcode', 'Shortcode', array($this, 'ichcpt_shortcode_mb'), 'ich_cpt', 'side');
        add_meta_box( 'ichcpt_settings', 'Settings', array($this, 'ichcpt_settings_mb'), 'ich_cpt');
        add_meta_box( 'ichcpt_pro', 'Image Caption Hover', array($this, 'ichcpt_pro_mb'), 'ich_cpt', 'side');
    }

    function ichcpt_shortcode_mb(){
        global $post;
        if (isset($post->ID)) {
            echo '<p style="text-align:center;">[ichcpt id="'.$post->ID.'"]</p>';
            
        } else {
            echo 'Please Save settings to get shortcode';
        }
    }

    function ichcpt_settings_mb(){
        include 'cpt_inc/settings_box.php';
    }

    function ichcpt_pro_mb(){
        ?>
            <p class="description">
                <?php _e( 'Having trouble setting up?', 'image-caption-hover' ); ?>
                <a target="_blank" href="http://webcodingplace.com/how-to-use-image-caption-hover-wordpress-plugin/"><?php _e( 'How to use', 'image-caption-hover' ); ?></a>
                <?php _e( 'OR', 'image-caption-hover' ); ?>
                <a target="_blank" href="http://webcodingplace.com/contact-us/"><?php _e( 'contact us for help', 'image-caption-hover' ); ?></a>
            </p>
            <hr>
            
            <h3>Image Caption Hover Pro Features</h3>
            <ol>
                <li><?php _e( 'Audio Sound Effects on Hover', 'image-caption-hover' ); ?></li>
                <li><?php _e( 'Responsive PopUp', 'image-caption-hover' ); ?></li>
                <li><?php _e( 'Custom Animation Speed', 'image-caption-hover' ); ?></li>
                <li><?php _e( '60+ More Hover Effects', 'image-caption-hover' ); ?></li>
                <li><?php _e( 'Display Caption at Bottom or Top', 'image-caption-hover' ); ?></li>
                <li><?php _e( 'Custom Width and Height', 'image-caption-hover' ); ?></li>
                <li><?php _e( 'Borders and Frames', 'image-caption-hover' ); ?></li>
            </ol>
            <a style="width: 100%; text-align:center;" target="_blank" class="button button-primary button-hero" href="http://webcodingplace.com/wordpress-pro-plugins/image-caption-hover-pro-wordpress-plugin/">
                <?php _e( 'Unlock Pro Features', 'image-caption-hover' ); ?>
            </a>
        <?php
    }    

    /* Prints the box content */
    function ichcpt_contents_mb() {
        // Use nonce for verification
        wp_nonce_field( plugin_basename( __FILE__ ), 'wcp_fgg_nonce' );
        include 'cpt_inc/render_box_contents.php';
    }

    function saving_ich_cpt( $post_id ) {
        // verify if this is an auto save routine. 
        // If it is our form has not been submitted, so we dont want to do anything
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
            return;

        // verify this came from the our screen and with proper authorization,
        // because save_post can be triggered at other times
        if ( !isset( $_POST['wcp_fgg_nonce'] ) )
            return;

        if ( !wp_verify_nonce( $_POST['wcp_fgg_nonce'], plugin_basename( __FILE__ ) ) )
            return;

        // OK, we're authenticated: we need to find and save the data

        $wcp_images = $_POST['ich_cpt'];
        $wcp_settings = $_POST['ichcpt_settings'];

        update_post_meta($post_id,'ich_cpt',$wcp_images);
        update_post_meta($post_id,'ichcpt_settings',$wcp_settings);
    }

    function ich_cpt_column_head($defaults){
        $defaults['fgg_col'] = 'Shortcode';
        return $defaults;       
    }

    function ich_cpt_column_content($column_name, $gallery_id){
        if ($column_name == 'fgg_col') {
            echo '[ichcpt id="'.$gallery_id.'"]';
        }
    }

}
?>